==> bplan-base-globals-1.14.1-2bb234.zip: src/Actions/TenantRecord/UpdateActiveStatus.php <==
<?php
/**
 * Update Action Class
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Actions
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <https://www.bplan-solutions.de/>
 * /Δ\
 */

namespace BplanBase\Globals\Actions\TenantRecord;


use App\Models\TenantRecord as DerivedTenantRecord;
use BplanBase\Globals\Models\TenantRecord;


/**
 * Update Action Class
 *
 * @version     1.0.0 / 2025-05-26
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 */
class UpdateActiveStatus
{

/* +++ TRAITS +++ +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */


/* +++ CLASS CONSTANTS +++ ++++++++++++++++++++++++++++++++++++++++++++++++++ */


/* +++ OBJECT MEMBERS +++ +++++++++++++++++++++++++++++++++++++++++++++++++++ */


/* +++ CLASS MEMBERS +++ ++++++++++++++++++++++++++++++++++++++++++++++++++++ */


/* +++ OBJECT METHODS +++ +++++++++++++++++++++++++++++++++++++++++++++++++++ */


    /**
     *
     * @param       int|string|TenantRecord|DerivedTenantRecord $tenantRecord
     *
     * @param       bool $status
     *
     * @return      TenantRecord|DerivedTenantRecord
     *
     * @version     1.0.0 / 2025-05-26
     * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
     * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
     */
    public function execute(int|string|TenantRecord|DerivedTenantRecord $tenantRecord, bool $status): TenantRecord|DerivedTenantRecord
    {
        if ($tenantRecord instanceof TenantRecord) {
            $Model = $tenantRecord;
        } else {
            $Model = TenantRecord::findOrFail($tenantRecord);
        }
        $Model->active = $status;

        $Model->save();

        return $Model;

    } // execute()


/* +++ CLASS METHODS +++ ++++++++++++++++++++++++++++++++++++++++++++++++++++ */


} // class UpdateActiveStatus {}

==> bplan-base-globals-2.0.0-380a93.zip: src/Actions/TenantRecord/UpdateActiveStatus.php <==
<?php
/**
 * Update Action Class
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Actions
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <https://www.bplan-solutions.de/>
 * /Δ\
 */

namespace BplanBase\Globals\Actions\TenantRecord;


use BplanBase\Globals\Foundation\Actions\BaseAction;
use BplanBase\Globals\Models\TenantRecord;
use Illuminate\Database\Eloquent\Model;


/**
 * Update Action Class
 *
 * @version     1.0.0 / 2025-05-26
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 */
class UpdateActiveStatus extends BaseAction
{

/* +++ TRAITS +++ +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */


/* +++ CLASS CONSTANTS +++ ++++++++++++++++++++++++++++++++++++++++++++++++++ */


/* +++ OBJECT MEMBERS +++ +++++++++++++++++++++++++++++++++++++++++++++++++++ */


/* +++ CLASS MEMBERS +++ ++++++++++++++++++++++++++++++++++++++++++++++++++++ */


    /**
     * @var     string $_modelClass
     */
    protected string $_modelClass = TenantRecord;


/* +++ OBJECT METHODS +++ +++++++++++++++++++++++++++++++++++++++++++++++++++ */


    /**
     *
     * @param       int|string|TenantRecord $tenantRecord
     *
     * @param       bool $status
     *
     * @return      TenantRecord
     *
     * @version     1.0.0 / 2025-05-26
     * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
     * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
     */
    public function execute(int|string|Model $tenantRecord, bool $status): Model
    {
        $Model = $this->_resolveModel($tenantRecord);

        $Model->active = $status;

        $Model->save();

        return $Model;

    } // execute()


/* +++ CLASS METHODS +++ ++++++++++++++++++++++++++++++++++++++++++++++++++++ */


} // class UpdateActiveStatus extends BaseAction {}
